/* nppt.h - format input as paper tape in a variety of ways (header).  */
/* RCS: $Id: nppt.h,v 1.6 2004/06/06 12:51:43 jsm28 Exp $ */

/* Copyright (c) 1998, 1999, 2004 Joseph Samuel Myers.  All rights reserved.
 *
 * This file is part of nppt, a program to format its input in a
 * representation of paper tape.
 *
 * Nppt is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * Nppt is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with nppt; see the file COPYING.  If not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef NPPT_H
#define NPPT_H		1

#define VERSION		"nppt 0.4\n"
#define DEFAULT_FORMAT	"BSD"

struct tape_operations {
  void (*start_tape)(void); /* Function to start the tape */
  void (*print_character)(unsigned int, int); /* Function to print
					       * one character */
  void (*end_tape)(void); /* Function to end the tape */
};

struct tape_type {
  const char *name; /* Name of the tape type */
  const char *desc; /* Description */
  unsigned int max; /* Max value punchable */
  unsigned int bits; /* Number of bits punchable */
  struct tape_operations ops; /* Operations on the tape */
  const void *params; /* Parameters for these operations */
};

extern const struct tape_operations *tape;
extern const void *tape_params;
extern unsigned int tape_max;
extern unsigned int tape_bits;

extern const struct tape_type horiz_tape_types[];
extern const struct tape_type vert_tape_types[];
extern const struct tape_type ps_tape_types[];

extern int show_text_flag;
extern unsigned long screen_columns;
extern int override_screen_columns_flag;

#endif /* !defined(NPPT_H) */
