/* util.h - header for utility functions.  */
/* RCS: $Id: util.h,v 1.4 1999/01/11 00:24:34 jsm28 Exp $ */

/* Copyright (c) 1997, 1998, 1999 Joseph Samuel Myers.  All rights reserved.
 *
 * This file is part of nppt, a program to format its input in a
 * representation of paper tape.
 *
 * Nppt is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * Nppt is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with nppt; see the file COPYING.  If not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef UTIL_H
#define UTIL_H		1

/* Includes */

#include <stdarg.h>
#include <stddef.h>
#include <stdio.h>
#include <sys/types.h>

extern const char *program_name; /* Name of the program */

/* Functions */

void get_program_name(const char *arg0); /* Get the name of the program */

#ifdef __GNUC__
void die(const char *format, ...)
     __attribute__((__noreturn__, __format__(__printf__, 1, 2)));
     /* Print an error and exit */
void xvfprintf(FILE *stream, const char *filename, const char *format,
	       va_list args) __attribute__((__format__(__printf__, 3, 0)));
     /* Print a message, checking for errors */
void xfprintf(FILE *stream, const char *filename, const char *format, ...)
     __attribute__((__format__(__printf__, 3, 4))); /* Likewise */
void xprintf(const char *format, ...)
     __attribute__((__format__(__printf__, 1, 2))); /* Likewise */
void warning(const char *format, ...)
     __attribute__((__format__(__printf__, 1, 2))); /* Print a warning */
#else /* Not GNU CC */
void die(const char *format, ...);
void xvfprintf(FILE *stream, const char *filename, const char *format,
	       va_list args);
void xfprintf(FILE *stream, const char *filename, const char *format, ...);
void xprintf(const char *format, ...);
void warning(const char *format, ...);
#endif /* Not GNU CC */

void xfputs(const char *string, FILE *stream, const char *filename);
void xputs(const char *string); /* Print a string with error check.  Does
				 * NOT add newline.  */
void xflush(FILE *stream, const char *filename); /* Flush a stream and check
						  * for errors */
void xputc(int c, FILE *stream, const char *filename); /* Write a character
							* and check for
							* errors */

void *xmalloc(size_t size); /* Malloc or die */
void *xrealloc(void *buf, size_t size); /* Realloc or die */
void *xcalloc(size_t size); /* Allocate zeroed memory or die */
off_t filesize(const char *file); /* Size of file, or die on error */

#endif /* !defined(UTIL_H) */
